@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -34,12 +34,17 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include <stdarg.h>
 #include <string.h>
+#include <unistd.h>
 #include <errno.h>
 
-#include "internal.h"
+#include "ansi-colours.h"
 #include "open_memstream.h"
+#include "utils.h"
+
+#include "internal.h"
 
 static void
 prologue (FILE *fp)
@@ -59,42 +64,71 @@ prologue (FILE *fp)
   fprintf (fp, "debug: ");
 }
 
+/* Common debug function.
+ * Note: preserves the previous value of errno.
+ */
+static void
+debug_common (bool in_server, const char *fs, va_list args)
+{
+  if (!verbose)
+    return;
+
+  int err = errno;
+#ifndef WIN32
+  const int tty = isatty (fileno (stderr));
+#else
+  const int tty = 0;
+#endif
+  CLEANUP_FREE char *str_inner = NULL;
+  CLEANUP_FREE char *str_outer = NULL;
+  FILE *fp_inner, *fp_outer;
+  size_t len_inner = 0, len_outer = 0;
+
+  /* The "inner" string is the debug string before escaping. */
+  fp_inner = open_memstream (&str_inner, &len_inner);
+  if (fp_inner == NULL)
+    goto fail;
+  errno = err; /* so %m works */
+  vfprintf (fp_inner, fs, args);
+  if (close_memstream (fp_inner) == -1)
+    goto fail;
+
+  /* The "outer" string contains the prologue, escaped debug string and \n. */
+  fp_outer = open_memstream (&str_outer, &len_outer);
+  if (fp_outer == NULL) goto fail;
+
+  if (!in_server && tty) ansi_force_colour (ANSI_FG_BOLD_BLACK, fp_outer);
+
+  prologue (fp_outer);
+  c_string_quote (str_inner, fp_outer);
+
+  if (!in_server && tty) ansi_force_restore (fp_outer);
+  fprintf (fp_outer, "\n");
+  if (close_memstream (fp_outer) == -1)
+    goto fail;
+
+  if (!str_outer)
+    goto fail;
+
+  /* Send it to stderr as atomically as possible. */
+  fputs (str_outer, stderr);
+
+  errno = err; /* restore original value before return */
+  return;
+
+ fail:
+  /* Try to emit what we can. */
+  errno = err; /* so %m works */
+  vfprintf (stderr, fs, args);
+  fprintf (stderr, "\n");
+  errno = err; /* restore original value before return */
+}
+
 /* Note: preserves the previous value of errno. */
 NBDKIT_DLL_PUBLIC void
 nbdkit_vdebug (const char *fs, va_list args)
 {
-  int err = errno;
-  CLEANUP_FREE char *str = NULL;
-  size_t len = 0;
-  FILE *fp;
-
-  if (!verbose)
-    return;
-
-  fp = open_memstream (&str, &len);
-  if (fp == NULL) {
-  fail:
-    /* Try to emit what we can. */
-    errno = err;
-    vfprintf (stderr, fs, args);
-    fprintf (stderr, "\n");
-    return;
-  }
-
-  prologue (fp);
-
-  errno = err;
-  vfprintf (fp, fs, args);
-
-  fprintf (fp, "\n");
-  close_memstream (fp);
-
-  if (str)
-    fputs (str, stderr);
-  else
-    goto fail;
-
-  errno = err;
+  debug_common (false, fs, args);
 }
 
 /* Note: preserves the previous value of errno. */
@@ -103,39 +137,28 @@ nbdkit_debug (const char *fs, ...)
 {
   int err = errno;
   va_list args;
-  CLEANUP_FREE char *str = NULL;
-  size_t len = 0;
-  FILE *fp;
-
-  if (!verbose)
-    return;
-
-  fp = open_memstream (&str, &len);
-  if (fp == NULL) {
-  fail:
-    /* Try to emit what we can. */
-    va_start (args, fs);
-    errno = err;
-    vfprintf (stderr, fs, args);
-    va_end (args);
-    fprintf (stderr, "\n");
-    return;
-  }
-
-  prologue (fp);
 
   va_start (args, fs);
+  debug_common (false, fs, args);
+  va_end (args);
+
   errno = err;
-  vfprintf (fp, fs, args);
+}
+
+/* This variant of debug is used when debug is called from the server
+ * code, via the debug() macro.
+ *
+ * Note: preserves the previous value of errno.
+ */
+void
+debug_in_server (const char *fs, ...)
+{
+  int err = errno;
+  va_list args;
+
+  va_start (args, fs);
+  debug_common (true, fs, args);
   va_end (args);
 
-  fprintf (fp, "\n");
-  close_memstream (fp);
-
-  if (str)
-    fputs (str, stderr);
-  else
-    goto fail;
-
   errno = err;
 }
