@@ -40,29 +40,54 @@
 
 #include "internal.h"
 
+/* Copy the error message to threadlocal.  This is sent to callers
+ * which are using structured replies, but is for extra information
+ * only so don't fail if we are unable to copy it.
+ */
+static void
+copy_error_to_threadlocal (int orig_errno, const char *fs, va_list args)
+{
+  va_list args_copy;
+  char *msg;
+  int r;
+
+  va_copy (args_copy, args);
+  errno = orig_errno;        /* must restore in case fs contains %m */
+  r = vasprintf (&msg, fs, args_copy);
+  va_end (args_copy);
+  if (r != -1 && msg)
+    threadlocal_set_last_error (msg); /* ownership passed to threadlocal */
+}
+
 /* Call the right log_*_verror function depending on log_sink.
  * Note: preserves the previous value of errno.
  */
 void
 log_verror (const char *fs, va_list args)
 {
+  int orig_errno = errno;
+
+  copy_error_to_threadlocal (orig_errno, fs, args);
+
   switch (log_to) {
   case LOG_TO_DEFAULT:
     if (forked_into_background)
-      log_syslog_verror (fs, args);
+      log_syslog_verror (orig_errno, fs, args);
     else
-      log_stderr_verror (fs, args);
+      log_stderr_verror (orig_errno, fs, args);
     break;
   case LOG_TO_SYSLOG:
-    log_syslog_verror (fs, args);
+    log_syslog_verror (orig_errno, fs, args);
     break;
   case LOG_TO_STDERR:
-    log_stderr_verror (fs, args);
+    log_stderr_verror (orig_errno, fs, args);
     break;
   case LOG_TO_NULL:
     /* nothing */
     break;
   }
+
+  errno = orig_errno; /* Restore errno before leaving the function. */
 }
 
 /* Note: preserves the previous value of errno. */
