@@ -44,6 +44,7 @@ enum {
   DUMP_PLUGIN_OPTION,
   EXIT_WITH_PARENT_OPTION,
   FILTER_OPTION,
+  KEEPALIVE_OPTION,
   LOG_OPTION,
   LONG_OPTIONS_OPTION,
   MASK_HANDSHAKE_OPTION,
@@ -54,6 +55,7 @@ enum {
   SELINUX_LABEL_OPTION,
   SHORT_OPTIONS_OPTION,
   SWAP_OPTION,
+  TIMEOUT_OPTION,
   TLS_OPTION,
   TLS_CERTIFICATES_OPTION,
   TLS_PSK_OPTION,
@@ -79,6 +81,8 @@ static const struct option long_options[] = {
   { "help",             no_argument,       NULL, HELP_OPTION },
   { "ip-addr",          required_argument, NULL, 'i' },
   { "ipaddr",           required_argument, NULL, 'i' },
+  { "keepalive",        no_argument,       NULL, KEEPALIVE_OPTION },
+  { "keep-alive",       no_argument,       NULL, KEEPALIVE_OPTION },
   { "log",              required_argument, NULL, LOG_OPTION },
   { "long-options",     no_argument,       NULL, LONG_OPTIONS_OPTION },
   { "mask-handshake",   required_argument, NULL, MASK_HANDSHAKE_OPTION },
@@ -106,6 +110,8 @@ static const struct option long_options[] = {
   { "stdin",            no_argument,       NULL, 's' },
   { "swap",             no_argument,       NULL, SWAP_OPTION },
   { "threads",          required_argument, NULL, 't' },
+  { "timeout",          required_argument, NULL, TIMEOUT_OPTION },
+  { "time-out",         required_argument, NULL, TIMEOUT_OPTION },
   { "tls",              required_argument, NULL, TLS_OPTION },
   { "tls-certificates", required_argument, NULL, TLS_CERTIFICATES_OPTION },
   { "tls-psk",          required_argument, NULL, TLS_PSK_OPTION },
