@@ -235,8 +235,14 @@ handle_request (uint16_t cmd, uint16_t flags, uint64_t offset, uint32_t count,
   int err = 0;
 
   /* Clear the error, so that we know if the plugin calls
-   * nbdkit_set_error() or relied on errno.  */
-  threadlocal_set_error (0);
+   * nbdkit_set_error() or relied on errno.
+   */
+  threadlocal_set_errno (0);
+
+  /* Also clear the last error in this thread so we will only save
+   * nbdkit_error() from this request.
+   */
+  threadlocal_clear_last_error ();
 
   switch (cmd) {
   case NBD_CMD_READ:
